@@ -72,8 +72,10 @@ static std::map<std::string, std::string> _create_extMimeTypes()
   extMimeTypes["epub"] = "application/epub+zip";
   extMimeTypes["PDF"] = "application/pdf";
   extMimeTypes["pdf"] = "application/pdf";
-  extMimeTypes["OGG"] = "application/ogg";
-  extMimeTypes["ogg"] = "application/ogg";
+  extMimeTypes["OGG"] = "audio/ogg";
+  extMimeTypes["ogg"] = "audio/ogg";
+  extMimeTypes["OGV"] = "video/ogg";
+  extMimeTypes["ogv"] = "video/ogg";
   extMimeTypes["JS"] = "application/javascript";
   extMimeTypes["js"] = "application/javascript";
   extMimeTypes["JSON"] = "application/json";
@@ -88,8 +90,28 @@ static std::map<std::string, std::string> _create_extMimeTypes()
   extMimeTypes["TTF"] = "application/font-ttf";
   extMimeTypes["woff"] = "application/font-woff";
   extMimeTypes["WOFF"] = "application/font-woff";
+  extMimeTypes["woff2"] = "application/font-woff2";
+  extMimeTypes["WOFF2"] = "application/font-woff2";
   extMimeTypes["vtt"] = "text/vtt";
   extMimeTypes["VTT"] = "text/vtt";
+  extMimeTypes["webm"] = "video/webm";
+  extMimeTypes["WEBM"] = "video/webm";
+  extMimeTypes["mp4"] = "video/mp4";
+  extMimeTypes["MP4"] = "video/mp4";
+  extMimeTypes["doc"] = "application/msword";
+  extMimeTypes["DOC"] = "application/msword";
+  extMimeTypes["docx"] = "application/vnd.openxmlformats-officedocument.wordprocessingml.document";
+  extMimeTypes["DOCX"] = "application/vnd.openxmlformats-officedocument.wordprocessingml.document";
+  extMimeTypes["ppt"] = "application/vnd.ms-powerpoint";
+  extMimeTypes["PPT"] = "application/vnd.ms-powerpoint";
+  extMimeTypes["odt"] = "application/vnd.oasis.opendocument.text";
+  extMimeTypes["ODT"] = "application/vnd.oasis.opendocument.text";
+  extMimeTypes["odp"] = "application/vnd.oasis.opendocument.text";
+  extMimeTypes["ODP"] = "application/vnd.oasis.opendocument.text";
+  extMimeTypes["zip"] = "application/zip";
+  extMimeTypes["ZIP"] = "application/zip";
+  extMimeTypes["wasm"] = "application/wasm";
+  extMimeTypes["WASM"] = "application/wasm";
 
   return extMimeTypes;
 }
@@ -129,7 +151,6 @@ inline std::string inflateString(const std::string& str)
     if (outstring.size() < zs.total_out) {
       outstring.append(outbuffer, zs.total_out - outstring.size());
     }
-
   } while (ret == Z_OK);
 
   inflateEnd(&zs);
@@ -326,7 +347,7 @@ std::vector<std::string> split(const std::string& lhs, const char* rhs)
 std::string computeAbsolutePath(const std::string& path,
                                 const std::string& relativePath)
 {
-  /* Add a trailing / to the path if necessary */
+  /* Remove leaf part of the path if not already a directory */
   std::string absolutePath = path[path.length() - 1] == '/'
                                  ? path
                                  : removeLastPathElement(path, false, false);
@@ -490,13 +511,13 @@ std::string getMimeTypeForFile(const std::string& filename)
     mimeType = filename.substr(index_of_last_dot + 1);
     try {
       return extMimeTypes.at(mimeType);
-    } catch (std::out_of_range) {}
+    } catch (std::out_of_range&) {}
   }
 
   /* Try to get the mimeType from the cache */
   try {
     return fileMimeTypes.at(filename);
-  } catch (std::out_of_range) {}
+  } catch (std::out_of_range&) {}
 
   /* Try to get the mimeType with libmagic */
   try {
@@ -526,6 +547,7 @@ std::string getNamespaceForMimeType(const std::string& mimeType)
   } else {
     if (mimeType == "application/font-ttf"
         || mimeType == "application/font-woff"
+        || mimeType == "application/font-woff2"
         || mimeType == "application/vnd.ms-opentype"
         || mimeType == "application/vnd.ms-fontobject"
         || mimeType == "application/javascript"
